import Phaser from 'phaser';

class Example extends Phaser.Scene
{
  constructor () {
    super();
  }

  preload () {
    this.load.image('tiles', '/assets/tilesets/1.png');
  }

  /**
   *       tile width: 63,
   *       tile height: 32,
   *       total w: 640,
   *       total h: 4000,
   */

  create () {
    const mapData = new Phaser.Tilemaps.MapData({
      width: 63,
      height: 32,
      tileWidth: 63,
      tileHeight: 32,
      orientation: Phaser.Tilemaps.Orientation.ISOMETRIC,
      format: Phaser.Tilemaps.Formats.ARRAY_2D
    });

    const map = new Phaser.Tilemaps.Tilemap(this, mapData);
    const tileset = map.addTilesetImage('1', 'tiles');
    const layer = map.createBlankLayer('layer', tileset, 350, 200);

    const data = [
      [ 1, 2, 1, 1, 1, 1, 1, 1, 1, 1 ],
      [ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ],
      [ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ],
      [ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ],
      [ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ],
      [ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ],
      [ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ],
      [ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ],
      [ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ],
      [ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ],
    ];

    let y = 0;

    data.forEach(row => {
      row.forEach((tile, x) => {
        layer.putTileAt(tile, x, y);
      });
      y++;
    });

    var cam = this.cameras.main;

    this.input.on("pointermove", function (p) {
      if (!p.isDown) return;

      cam.scrollX -= (p.x - p.prevPosition.x) / cam.zoom;
      cam.scrollY -= (p.y - p.prevPosition.y) / cam.zoom;
    });
  }
}

export default Example;